<?php

namespace Asadi\Development\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Development\Interfaces\DevelopmentRepositoryInterface;
use Asadi\Development\Repositories\Presenter\DevelopmentItemTransformer;

/**
 * Pubic API controller class.
 */
class DevelopmentPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Development\Interfaces\DevelopmentRepositoryInterface $development
     *
     * @return type
     */
    public function __construct(DevelopmentRepositoryInterface $development)
    {
        $this->repository = $development;
        parent::__construct();
    }

    /**
     * Show development's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $developments = $this->repository
            ->setPresenter('\\Asadi\\Development\\Repositories\\Presenter\\DevelopmentListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $developments['code'] = 2000;
        return response()->json($developments)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show development.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $development = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($development)) {
            $development         = $this->itemPresenter($module, new DevelopmentItemTransformer);
            $development['code'] = 2001;
            return response()->json($development)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
