<?php

namespace Asadi\Development\Http\Controllers;
use Litepie\Development\Http\Requests\DevelopmentRequest;
use Litepie\Development\Models\Development;

trait DevelopmentWorkflow {
	
    /**
     * Workflow controller function for development.
     *
     * @param Model   $development
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(DevelopmentRequest $request, Development $development, $step)
    {

        try {

            $development->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('development::development.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/development/development/' . $development->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/development/development/' . $development->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for development.
     *
     * @param Model   $development
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Development $development, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $development->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('development::development.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('development::admin.development.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('development::admin.development.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('development::admin.development.message', $data)->render();

        }

    }
}