<?php

namespace Asadi\Development\Policies;

use App\User;
use Asadi\Development\Models\Development;

class DevelopmentPolicy
{

    /**
     * Determine if the given user can view the development.
     *
     * @param User $user
     * @param Development $development
     *
     * @return bool
     */
    public function view(User $user, Development $development)
    {
        if ($user->canDo('development.development.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $development->user_id;
    }

    /**
     * Determine if the given user can create a development.
     *
     * @param User $user
     * @param Development $development
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('development.development.create');
    }

    /**
     * Determine if the given user can update the given development.
     *
     * @param User $user
     * @param Development $development
     *
     * @return bool
     */
    public function update(User $user, Development $development)
    {
        if ($user->canDo('development.development.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $development->user_id;
    }

    /**
     * Determine if the given user can delete the given development.
     *
     * @param User $user
     * @param Development $development
     *
     * @return bool
     */
    public function destroy(User $user, Development $development)
    {
        if ($user->canDo('development.development.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $development->user_id;
    }

    /**
     * Determine if the given user can verify the given development.
     *
     * @param User $user
     * @param Development $development
     *
     * @return bool
     */
    public function verify(User $user, Development $development)
    {
        if ($user->canDo('development.development.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('development.development.verify') 
        && $user->is('manager')
        && $development->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given development.
     *
     * @param User $user
     * @param Development $development
     *
     * @return bool
     */
    public function approve(User $user, Development $development)
    {
        if ($user->canDo('development.development.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
