<?php

namespace Asadi\Development\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Development\Models\Development;

class DevelopmentAction
{
    /**
     * Perform the complete action.
     *
     * @param Development $development
     *
     * @return Development
     */
    public function complete(Development $development)
    {
        try {
            $development->status = 'complete';
            return $development->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Development $development
     *
     * @return Development
     */public function verify(Development $development)
    {
        try {
            $development->status = 'verify';
            return $development->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Development $development
     *
     * @return Development
     */public function approve(Development $development)
    {
        try {
            $development->status = 'approve';
            return $development->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Development $development
     *
     * @return Development
     */public function publish(Development $development)
    {
        try {
            $development->status = 'publish';
            return $development->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Development $development
     *
     * @return Development
     */
    public function archive(Development $development)
    {
        try {
            $development->status = 'archive';
            return $development->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Development $development
     *
     * @return Development
     */
    public function unpublish(Development $development)
    {
        try {
            $development->status = 'unpublish';
            return $development->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
