<?php

namespace Asadi\Development\Workflow;

use Asadi\Development\Models\Development;
use Validator;

class DevelopmentValidator
{

    /**
     * Determine if the given development is valid for complete status.
     *
     * @param Development $development
     *
     * @return bool / Validator
     */
    public function complete(Development $development)
    {
        return Validator::make($development->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given development is valid for verify status.
     *
     * @param Development $development
     *
     * @return bool / Validator
     */
    public function verify(Development $development)
    {
        return Validator::make($development->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given development is valid for approve status.
     *
     * @param Development $development
     *
     * @return bool / Validator
     */
    public function approve(Development $development)
    {
        return Validator::make($development->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given development is valid for publish status.
     *
     * @param Development $development
     *
     * @return bool / Validator
     */
    public function publish(Development $development)
    {
        return Validator::make($development->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given development is valid for archive status.
     *
     * @param Development $development
     *
     * @return bool / Validator
     */
    public function archive(Development $development)
    {
        return Validator::make($development->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given development is valid for unpublish status.
     *
     * @param Development $development
     *
     * @return bool / Validator
     */
    public function unpublish(Development $development)
    {
        return Validator::make($development->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
